@@ -2,13 +2,16 @@
 #'
 #' @description Forced Choice in Item Response Theory
 #'
-#' @docType package
+#' @keywords internal
+"_PACKAGE"
 #' @name fcirt-package
 #' @aliases fcirt-package
 #' @useDynLib fcirt, .registration = TRUE
 #' @import methods
 #' @import Rcpp
 #' @importFrom rstan sampling
+#' @importFrom RcppParallel RcppParallelLibs
+#' @import rstantools
 #'
 #' @references
 #' Stan Development Team (2020). RStan: the R interface to Stan. R package version 2.21.2. https://mc-stan.org
